#!/bin/bash

# Master / slave directories
dbm=$DBDIR/rs0
dbs=$DBDIR/rs1

function clean {
	killall -9 -w mongod
	sleep 2
	rm -rf $dbm $dbs
	mkdir -p $dbm
	mkdir -p $dbs
} 

function start {
	# Start the master
	LD_LIBRARY_PATH=$WT_INSTALL/lib:$LD_LIBRARY_PATH ./mongod \
	    --dbpath=$dbm --replSet rs --port 27017 --fork --logpath=$dbm/MDB.log
	# Start the slave
	echo "==== Start the slave mongod ===="
	LD_LIBRARY_PATH=$WT_INSTALL/lib:$LD_LIBRARY_PATH ./mongod \
	    --dbpath=$dbs --replSet rs --port 27018 --fork --logpath=$dbs/MDB.log
	echo "==== Initiate the replica set ===="
	mongo --port 27017 --eval 'rs.initiate( { _id: "rs", members: [{ _id: 0, host: "localhost:27017"}]} )'
	echo "==== Add slave to group ===="
	sleep 2
	mongo --port 27017 --eval 'rs.add("localhost:27018")'
}

function insert {
	(
	for t in $(seq 5); do
	    mongo --port 27017 --eval "
	        x = ''
	        for (var i=0; i<800; i++)
            	x += 'x'
        	docs = []
        	for (var i=0; i<1000; i++)
            	    docs.push({x:x})
	        ops = [{
	            op: 'insert',
	            ns: 'test.c' + '$t',
	            doc: docs,
	        }]
	        res = benchRun({
	            ops: ops,
	            seconds: 360,
	            parallel: 1
	        })
	    " &
	done
	wait
	)
}

clean; start
echo "==== Startup done. Run test ===="
insert
